@@ -3,7 +3,7 @@
 # pygenda_calendar.py
 # Connects to agenda data provider - either an ics file or CalDAV server.
 #
-# Copyright (C) 2022 Matthew Lewis
+# Copyright (C) 2022,2023 Matthew Lewis
 #
 # This file is part of Pygenda.
 #
@@ -20,7 +20,7 @@
 # along with Pygenda. If not, see <https://www.gnu.org/licenses/>.
 
 
-from icalendar import Calendar as iCalendar, Event as iEvent, Todo as iTodo, vRecur
+from icalendar import Calendar as iCalendar, Event as iEvent, Todo as iTodo, Alarm as iAlarm, vRecur
 from datetime import timedelta, datetime as dt_datetime, time as dt_time, date as dt_date, timezone
 from dateutil.relativedelta import relativedelta
 from dateutil.rrule import rrulestr
@@ -111,8 +111,8 @@ class Calendar:
     @staticmethod
     def gen_uid() -> str:
         # Generate a UID for iCal elements (required element)
-        uid = 'Pygenda-{}'.format(uuid1())
-        return uid
+        uid = uuid1() # based on MAC addr, time & random element
+        return str(uid)
 
 
     @classmethod
@@ -151,6 +151,8 @@ class Calendar:
         if e_inf.priority:
             en.add('PRIORITY', e_inf.priority)
 
+        cls._entry_set_alarms_from_info(en, e_inf)
+
         entry = cls.calConnector.add_entry(en) # Write to store
         return entry
 
@@ -184,6 +186,7 @@ class Calendar:
         en.add('SUMMARY', summ)
         new_dt_start = None
         if en_is_event:
+            # Some entry elements only relevant if an event (may change later)
             ex_dt_start = exen['DTSTART'].dt if 'DTSTART' in exen else None
             if dt_start:
                 if ex_dt_start:
@@ -202,6 +205,9 @@ class Calendar:
                 delta = new_dt_start - ex_dt_start
                 new_dt_end = ex_dt_end + delta
                 en.add('DTEND', new_dt_end)
+            alms = exen.walk('VALARM')
+            for alm in alms:
+                en.add_component(deepcopy(alm)) # Not sure need dc, but safer
 
         if 'LOCATION' in exen:
             en.add('LOCATION', exen['LOCATION'])
@@ -219,7 +225,9 @@ class Calendar:
             exen_status = exen['STATUS']
             if exen_status in sl:
                 en.add('STATUS', exen_status)
+
         en = cls.calConnector.add_entry(en) # Write to store
+
         if new_dt_start is not None:
             cls._entry_norep_list_sorted = None # Clear norep cache as modified
         if not en_is_event: # is Todo
@@ -299,6 +307,12 @@ class Calendar:
         cls._entry_set_status_from_info(en, e_inf)
         cls._event_set_location_from_info(en, e_inf)
 
+        # First delete alarms before adding requested ones
+        alms = en.walk('VALARM')
+        for alm in alms:
+            en.subcomponents.remove(alm)
+        cls._entry_set_alarms_from_info(en, e_inf)
+
         # This needs optimising - some cases cause too much cache flushing !!
         if clear_norep:
             cls._entry_norep_list_sorted = None
@@ -401,6 +415,37 @@ class Calendar:
             ev.add('LOCATION', e_inf.location)
 
 
+    @staticmethod
+    def _entry_set_alarms_from_info(en:Union[iEvent,iTodo], e_inf:EntryInfo) -> None:
+        # Set entry alarms from e_inf
+        for al in e_inf.alarms:
+            v_alm = iAlarm()
+            v_alm.add('TRIGGER', al.tdelta)
+            v_alm.add('ACTION', al.action)
+            desc = al.desc
+            summ = al.summary
+            attee = al.attendee
+            if al.action=='DISPLAY':
+                # Description required for Display
+                if desc is None:
+                    desc = ''
+            elif al.action=='EMAIL':
+                # Description, Summary, Attendee required for Email
+                if desc is None:
+                    desc = ''
+                if summ is None:
+                    summ = ''
+                if attee is None:
+                    attee = ''
+            if desc is not None:
+                v_alm.add('DESCRIPTION', desc)
+            if summ is not None:
+                v_alm.add('SUMMARY', summ)
+            if attee is not None:
+                v_alm.add('ATTENDEE', attee)
+            en.add_component(v_alm)
+
+
     @classmethod
     def delete_entry(cls, entry:Union[iEvent,iTodo]) -> None:
         # Delete given entry.
@@ -542,9 +587,26 @@ class Calendar:
         for ev in cls._entry_rep_list:
             if 'SUMMARY' in ev and txt_n in ev['SUMMARY'].casefold():
                 ret_list.append(ev)
+        # Todo entries
+        cls._update_todo_list()
+        for td in cls._todo_list:
+            if 'SUMMARY' in td and txt_n in td['SUMMARY'].casefold():
+                ret_list.append(td)
         return ret_list
 
 
+    @staticmethod
+    def caldatetime_tree_to_dt_list(ed) -> list:
+        # Utility function to map a "tree" of dates (arg `ed`)
+        # (as returned by icalendar when retrieving EXDATE)
+        # to a flat list of Python date/datetimes.
+        if isinstance(ed, list):
+            exdate_list = [ed[i].dts[j] for i in range(len(ed)) for j in range(len(ed[i].dts))]
+        else:
+            exdate_list = ed.dts
+        return [d.dt for d in exdate_list]
+
+
 #
 # Connector class for ICS files
 #
@@ -731,7 +793,14 @@ class RepeatInfo:
             if self.subday_rpt:
                 # Need to do calculations in UTC (e.g. for summer time changes)
                 self.start = self.start.astimezone(timezone.utc)
-            start = date_to_datetime(start, True).astimezone(timezone.utc)
+            try:
+                start = date_to_datetime(start, True).astimezone(timezone.utc)
+            except OverflowError:
+                if start.year==1:
+                    # Underflow due to timezone, set start to earliest time pos
+                    start = dt_datetime(1,1,1,tzinfo=timezone.utc)
+                else:
+                    raise
             stop = date_to_datetime(stop, True).astimezone(timezone.utc)
         else:
             self.start = self.dtstart
@@ -1233,8 +1302,8 @@ def repeats_in_range_with_rrstr(ev:iEvent, start:dt_date, stop:dt_date) -> list:
         i_until_z = rrstr.find('Z', i_until_st)
         if i_until_z == -1 or i_until_z > i_until_end:
             rrstr = rrstr[:i_until_end] + 'Z' + rrstr[i_until_end:]
-    exd = 'EXDATE' in ev
-    rr = rrulestr(rrstr,dtstart=dt,forceset=exd)
+    has_exd = 'EXDATE' in ev
+    rr = rrulestr(rrstr,dtstart=dt,forceset=has_exd)
     st = date_to_datetime(start, is_timed)
     sp = date_to_datetime(stop, is_timed)
     sp -= timedelta(milliseconds=1)
@@ -1244,21 +1313,17 @@ def repeats_in_range_with_rrstr(ev:iEvent, start:dt_date, stop:dt_date) -> list:
     elif is_hr_min_sec:
         # After doing calculations in UTC, convert results to local time
         ret = [d.astimezone(LOCAL_TZ) for d in ret]
-    if exd:
-        if isinstance(ev['EXDATE'], list):
-            exdate_list = [ev['EXDATE'][i].dts[j] for i in range(len(ev['EXDATE'])) for j in range(len(ev['EXDATE'][i].dts))]
-        else:
-            exdate_list = ev['EXDATE'].dts
-        for de in exdate_list:
-            dedt = de.dt
+    if has_exd:
+        exdate_list = Calendar.caldatetime_tree_to_dt_list(ev['EXDATE'])
+        for exdt in exdate_list:
             if is_timed:
-                if isinstance(dedt, dt_datetime):
-                    dedt = date_to_datetime(dedt, True)
-                    ret = [d for d in ret if d!=dedt]
+                if isinstance(exdt, dt_datetime):
+                    exdt = date_to_datetime(exdt, True)
+                    ret = [d for d in ret if d!=exdt]
                 else:
-                    ret = [d for d in ret if d.date()!=dedt]
+                    ret = [d for d in ret if d.date()!=exdt]
             else:
-                ret = [d for d in ret if d!=dedt]
+                ret = [d for d in ret if d!=exdt]
     return ret
 
 
