@@ -4,7 +4,7 @@
 # "View" class definition - base class for Week View, Year View.
 # Provides default implementations of functions.
 #
-# Copyright (C) 2022 Matthew Lewis
+# Copyright (C) 2022,2023 Matthew Lewis
 #
 # This file is part of Pygenda.
 #
@@ -30,7 +30,8 @@ from icalendar import cal as iCal, Event as iEvent, Todo as iTodo
 from datetime import date as dt_date, datetime as dt_datetime, timedelta
 from typing import Optional, Union
 
-from .pygenda_gui import GUI, EventDialogController
+from .pygenda_gui import GUI
+from .pygenda_dialog_event import EventDialogController
 from .pygenda_util import datetime_to_time, datetime_to_date, date_to_datetime, format_time, format_compact_date, format_compact_time, format_compact_datetime, dt_lte
 from .pygenda_calendar import Calendar
 from .pygenda_entryinfo import EntryInfo
@@ -106,7 +107,7 @@ class View:
     def cursor_inc(cls, delta:timedelta, idx:int=None) -> None:
         # Add delta to current cursor date; optionally set index in date.
         # Call redraw on view.
-        View._cursor_date += delta
+        View._cursor_date += delta # raises OverflowError if out of range
         if idx is not None:
             View._cursor_idx_in_date = idx
         cls.redraw(en_changes=False)
@@ -174,7 +175,7 @@ class View:
     @staticmethod
     def entry_icons(ev:iCal.Event, prefix_space:bool) -> str:
         # Returns string of icons for entry (repeat, alarm...)
-        alarm = u'♫' # alternatives: alarm clock ⏰ (U+23F0), bell 🕭,🔔 (U+1F56D,U+1F514)
+        alarm = u'♫' # alternatives: alarm clock ⏰ (U+23F0), bell 🕭,🔔 (U+1F56D,U+1F514), speaker 🔊
         repeat = u'⟳'
         icons = ''
         if ev.walk('VALARM'):
@@ -309,7 +310,7 @@ class View_DayUnit_Base(View):
         # Handle pasting of text in Week/Year views.
         # Open a New Entry dialog with description initialised as txt
         date = cls.cursor_date()
-        GLib.idle_add(EventDialogController.newevent, txt, date)
+        GLib.idle_add(EventDialogController.new_event, txt, date)
 
 
     @classmethod
@@ -327,9 +328,9 @@ class View_DayUnit_Base(View):
         en = cls.get_cursor_entry()
         if en is None:
             date = cls.cursor_date()
-            EventDialogController.newevent(date=date)
+            EventDialogController.new_event(date=date)
         else:
-            EventDialogController.editevent(en)
+            GUI.edit_or_display_event(en)
 
 
     @classmethod
