@@ -3,7 +3,7 @@
 # pygenda_view_week.py
 # Provides the "Week View" for Pygenda.
 #
-# Copyright (C) 2022 Matthew Lewis
+# Copyright (C) 2022,2023 Matthew Lewis
 #
 # This file is part of Pygenda.
 #
@@ -35,7 +35,8 @@ from .pygenda_view import View, View_DayUnit_Base
 from .pygenda_calendar import Calendar
 from .pygenda_config import Config
 from .pygenda_util import start_of_week, day_in_week, month_abbr, start_end_dts_occ, dt_lte
-from .pygenda_gui import GUI, EventDialogController
+from .pygenda_gui import GUI
+from .pygenda_dialog_event import EventDialogController
 
 
 # Singleton class for Week View
@@ -73,6 +74,7 @@ class View_Week(View_DayUnit_Base):
         # Called on startup.
         # Gets view framework from glade file & tweaks/adds a few elements.
         # Returns widget containing view.
+        GUI.load_glade_file('view_week.glade')
         cls._topbox = GUI._builder.get_object('view_week')
         cls._month_label = GUI._builder.get_object('week_label_month')
         cls._weekno_label = GUI._builder.get_object('week_label_weekno')
@@ -444,7 +446,7 @@ class View_Week(View_DayUnit_Base):
             # !! Bug: only works for ASCII characters
             if ev.state & (Gdk.ModifierType.CONTROL_MASK|Gdk.ModifierType.MOD1_MASK)==0 and Gdk.KEY_exclam <= ev.keyval <= Gdk.KEY_asciitilde:
                 date = cls.cursor_date()
-                GLib.idle_add(EventDialogController.newevent, chr(ev.keyval), date)
+                GLib.idle_add(EventDialogController.new_event, chr(ev.keyval), date)
 
 
     @classmethod
