@@ -3,7 +3,7 @@
 # pygenda_view_year.py
 # Provides the "Year View" for Pygenda.
 #
-# Copyright (C) 2022 Matthew Lewis
+# Copyright (C) 2022,2023 Matthew Lewis
 #
 # This file is part of Pygenda.
 #
@@ -32,7 +32,8 @@ from typing import Tuple
 
 # pygenda components
 from .pygenda_view import View, View_DayUnit_Base
-from .pygenda_gui import GUI, EventDialogController
+from .pygenda_gui import GUI
+from .pygenda_dialog_event import EventDialogController
 from .pygenda_config import Config
 from .pygenda_calendar import Calendar
 from .pygenda_util import start_end_dts_occ
@@ -77,6 +78,7 @@ class View_Year(View_DayUnit_Base):
         # Called on startup.
         # Gets view framework from glade file & tweaks/adds a few elements.
         # Returns widget containing view.
+        GUI.load_glade_file('view_year.glade')
         cls._topbox = GUI._builder.get_object('view_year')
         cls._grid_cells = GUI._builder.get_object('year_grid_days')
         cls._date_label = GUI._builder.get_object('year_datelabel')
@@ -584,7 +586,7 @@ class View_Year(View_DayUnit_Base):
             pass
         if ev.state & (Gdk.ModifierType.CONTROL_MASK|Gdk.ModifierType.MOD1_MASK)==0 and Gdk.KEY_exclam <= ev.keyval <= Gdk.KEY_asciitilde:
             date = cls.cursor_date()
-            GLib.idle_add(EventDialogController.newevent, chr(ev.keyval), date, priority=GLib.PRIORITY_HIGH_IDLE+30)
+            GLib.idle_add(EventDialogController.new_event, chr(ev.keyval), date, priority=GLib.PRIORITY_HIGH_IDLE+30)
 
 
     @classmethod
